;**********************************************************************
;  SOUNDLIB
;----------------------------------------------------------------------
; by David Khling 1998
;
; How to hear the sound, that is outputted by Soundlib's routines:
;  The sound is played through the serial port. So everything you need
;  to do is to connect earphones with the port. This can be done, e.g.
;  by soldering the TI-92 to TI-92 link cable together with earphones:
;
;   ___________
;  |           |-------_ ---- _ ___      Solder together: 1 and 2;  3 and 4
;  |Plug of the|      | | 1  | | 3 \
;  |TI-92 to   |      |_|    |_|___/                  _____________
;  |TI-92 link |-------  ----                        |             \
;  |cable      |           ___  ------ _ -----------|  Plug of the  |
;  |           |          /2  ||  4   | |           |  earphones     \
;  |           |          \___||      |_|           |                 |
;  |           |                ------   -----------|                 |
;  |           |                                     |___________     |
;  |           |                                                 \     \
;    .........							    ....
;
;  (you aren't watching this with a proportional font, aren't you?)
;
;  You can additionally use hotglue or adhesive tape to stabilize the
;  whole thing.
;
; I take no responsibility, for any damage or loss of data that is
; caused by this library or by trying to connect the TI-92 with
; earphones, loudspeakers etc..
;
; Bugs/questions/suggestions/comments? (E)mail me!
;
;  Email: dkuehlin@hell1og.be.schule.de (don't mix up 'l' and '1')
;        - valid till june 2000 and only if I don't have hollidays
;          (since it is at my account at school)
;  Mail:
;         David Khling				(K&uuml;hling)
;         Lion-Feuchtwanger-Str. 44
;         12619 Berlin
;         GERMANY
;

;****************************************************************************
; These routines do not destroy any registers.				    *
;****************************************************************************

;****************************************************************************
;  Init									    *
;---------------------------------------------------------------------------*
; Tests the calculator's speed, and stores it for to be used by the sound   *
; routines.							            *
; (bewares compatability between TI-92, 256K TI-92, TI-92 II, TI-92+ and    *
; boosted calcs)							    *
; This routine MUST be called, before using one of the other routines!	    *
;****************************************************************************
soundlib::Init		EQU	soundlib@0000

;****************************************************************************
;  Sound								    *
;---------------------------------------------------------------------------*
; Plays a tone through the serial port.				    	    *
; Input:								    *
;	d0.w = frequency [Hz] (should be in about the range 40...4000)	    *
;	d1.w = duration (unit: 1/1024 seconds)				    *
; Output:								    *
;	tone is played							    *
;****************************************************************************
soundlib::Sound		EQU	soundlib@0001

;****************************************************************************
;  Pause								    *
;---------------------------------------------------------------------------*
; waits (similar to C's delay - function)				    *
; Input:								    *
;	d1.w = duration (unit: 1/1024 seconds)				    *
; Output:								    *
;	waits for the given duration  					    *
;****************************************************************************
soundlib::Pause		EQU	soundlib@0002

;****************************************************************************
;  Play 								    *
;---------------------------------------------------------------------------*
; Plays a tune.								    *
; Input:								    *
;  a0.l = pointer to tune data					    	    *
;									    *
;      Tune Format:							    *
;	   dc.b  command, parameter, command, parameter, ...., TEND	    *
;	  `command' is one of the equates, that are defined at the end of   *
;         this file.                                                        *
;									    *
;         If command is a note (equates _C0 - _B6) or `PAUSE', the parameter*
;	  is the tone/pause duration, with 128 being a full note, 32 a 	    *
;	  quater note etc.                                                  *
;									    *
;	  The command 'NOTED' sets the note fill duration, that is specified*
;         by the parameter.                                                 *
;          `dc.b NOTED,255' plays the following notes legato (plays 100% of *
;	   a tone)							    *
;          `dc.b NOTED,63' plays the following notes staccato (plays 25% of *
;	   a tone, and pauses the remaining 75%)			    *
;	  The default note fill duration is 224, which means, that about 88%*
;         of a tone are played, and the remaining 12% are paused.	    *
;									    *
;	  The command `TEMPO', sets the tempo in which the following notes  *
;         are played, measured by beats per minute. (one beat = duration #32*
;         = quater note) The default tempo is 120.   	                    *
;									    *
;	  !!! Never forget to end the tune by `TEND'!!!		    	    *
;									    *
;  a1.l = pointer to callback routine, that is called before each tone is   *
;	  played (set it to 0, if no routine should be called)		    *
;	  This routine is expected to don't change any register, d4         *
;	  excepted. If d4.b is not zero, after the callback routine was     *
;	  called, Play will exit. This can be used to abort a tune, when a  *
;	  key is pressed.						    *
;	  Contents of the registers, when the callback routine is called:   *
;	   (a0).b  = length of current note 				    *
;	   d0.w	   = current note (0 = C0, 1 = C#0, 2 = D, ..., 83 = B6)    *
;	   d3.w	   = number of current note (0 = 1st, 1 = 2nd...); can be   *
;		     used to display a song text, according to the melody   *
; Output:								    *
;	tune is played		  					    *
;****************************************************************************
soundlib::Play		EQU	soundlib@0003

;****************************************************************************
;  FrqTable 								    *
;---------------------------------------------------------------------------*
; pointer to Soundlib's frequency table 				    *
; Each entry is a word, the first entry is the freqency(Hz) of the tone C0, *
; the next is the freqency of C#0... till B6 (use the equates, that are     *
; listed below).							    *
;****************************************************************************
soundlib::FrqTable	EQU	soundlib@0004

;----------------------------------------------------------------------------
; Note Equates (to be used in tunes, that are to be played by
; soundlib::Play)
;----------------------------------------------------------------------------
_C0	EQU	0
_C#0	EQU	1
_Db0	EQU	1
_D0	EQU	2
_D#0	EQU	3
_Eb0	EQU	3
_E0	EQU	4
_F0	EQU	5
_F#0	EQU	6
_Gb0	EQU	6
_G0	EQU	7
_G#0	EQU	8
_Ab0	EQU	8
_A0	EQU	9
_A#0	EQU	10
_Bb0	EQU	10
_B0	EQU	11
_C1	EQU	12
_C#1	EQU	13
_Db1	EQU	13
_D1	EQU	14
_D#1	EQU	15
_Eb1	EQU	15
_E1	EQU	16
_F1	EQU	17
_F#1	EQU	18
_Gb1	EQU	18
_G1	EQU	19
_G#1	EQU	20
_Ab1	EQU	20
_A1	EQU	21
_A#1	EQU	22
_Bb1	EQU	22
_B1	EQU	23
_C2	EQU	24
_C#2	EQU	25
_Db2	EQU	25
_D2	EQU	26
_D#2	EQU	27
_Eb2	EQU	27
_E2	EQU	28
_F2	EQU	29
_F#2	EQU	30
_Gb2	EQU	30
_G2	EQU	31
_G#2	EQU	32
_Ab2	EQU	32
_A2	EQU	33
_A#2	EQU	34
_Bb2	EQU	34
_B2	EQU	35
_C3	EQU	36
_C#3	EQU	37
_Db3	EQU	37
_D3	EQU	38
_D#3	EQU	39
_Eb3	EQU	39
_E3	EQU	40
_F3	EQU	41
_F#3	EQU	42
_Gb3	EQU	42
_G3	EQU	43
_G#3	EQU	44
_Ab3	EQU	44
_A3	EQU	45
_A#3	EQU	46
_Bb3	EQU	46
_B3	EQU	47
_C4	EQU	48
_C#4	EQU	49
_Db4	EQU	49
_D4	EQU	50
_D#4	EQU	51
_Eb4	EQU	51
_E4	EQU	52
_F4	EQU	53
_F#4	EQU	54
_Gb4	EQU	54
_G4	EQU	55
_G#4	EQU	56
_Ab4	EQU	56
_A4	EQU	57
_A#4	EQU	58
_Bb4	EQU	58
_B4	EQU	59
_C5	EQU	60
_C#5	EQU	61
_Db5	EQU	61
_D5	EQU	62
_D#5	EQU	63
_Eb5	EQU	63
_E5	EQU	64
_F5	EQU	65
_F#5	EQU	66
_Gb5	EQU	66
_G5	EQU	67
_G#5	EQU	68
_Ab5	EQU	68
_A5	EQU	69
_A#5	EQU	70
_Bb5	EQU	70
_B5	EQU	71
_C6	EQU	72
_C#6	EQU	73
_Db6	EQU	73
_D6	EQU	74
_D#6	EQU	75
_Eb6	EQU	75
_E6	EQU	76
_F6	EQU	77
_F#6	EQU	78
_Gb6	EQU	78
_G6	EQU	79
_G#6	EQU	80
_Ab6	EQU	80
_A6	EQU	81
_A#6	EQU	82
_Bb6	EQU	82
_B6	EQU	83

;----------------------------------------------------------------------------
; Controll Character Equates (to be used in tunes, that are to be played by
; soundlib::Play)
;----------------------------------------------------------------------------
PAUSE	EQU	128
TEMPO	EQU	129
NOTED	EQU	130
TEND	EQU	131
